@@ -26,6 +26,8 @@
 #endif
 
 bool LockScreen::Debug;
+bool LockScreen::ScreenshotMode;
+QSettings* LockScreen::Settings;
 
 LockScreen::LockScreen()
 {
@@ -33,7 +35,6 @@ LockScreen::LockScreen()
 
     m_Scene.setSceneRect(0, 0, 800, 480);
     m_Scene.setItemIndexMethod(QGraphicsScene::NoIndex);
-    setBackground();
 
     m_View = new QGraphicsView(&m_Scene);
     m_View->setWindowFlags(Qt::Dialog);
@@ -45,6 +46,43 @@ LockScreen::LockScreen()
 
     m_WasPortrait = LsWidget::isPortrait();
     m_isDialogActive = false;
+
+    LsWidget::setOrientation(LsWidget::Auto);
+#ifdef Q_WS_MAEMO_5
+    QString orientation = LockScreen::Settings->value("Main/Orientation", "Auto").toString().toLower();
+    if (orientation == "landscape"){
+        LsWidget::setOrientation(LsWidget::Landscape);
+        m_View->setAttribute(Qt::WA_Maemo5LandscapeOrientation);
+        m_WasPortrait = false;
+    } else if (orientation == "portrait"){
+        LsWidget::setOrientation(LsWidget::Portrait);
+        m_View->setAttribute(Qt::WA_Maemo5PortraitOrientation);
+        m_WasPortrait = true;
+    }else{
+        m_View->setAttribute(Qt::WA_Maemo5AutoOrientation);
+        connect(QApplication::desktop(), SIGNAL(resized(int)), this, SLOT(onOrientationChanged(int)));
+        m_WasPortrait = !LsWidget::isPortrait();
+    }
+#else
+    QString orientation = LockScreen::Settings->value("Main/Orientation", "auto").toString().toLower();
+    if (orientation == "landscape"){
+        LsWidget::setOrientation(LsWidget::Landscape);
+        m_WasPortrait = false;
+    }else if (orientation == "portrait"){
+        LsWidget::setOrientation(LsWidget::Portrait);
+        m_WasPortrait = true;
+    }else{
+        m_WasPortrait = false;
+    }
+#endif
+    setBackground();
+    if (LsWidget::isPortrait()){
+        m_Scene.setSceneRect(0, 0, 480, 800);
+        m_View->setFixedSize(480, 800);
+    }else{
+        m_Scene.setSceneRect(0, 0, 800, 480);
+        m_View->setFixedSize(800, 480);
+    }
     createWidgets();
 
 #ifdef Q_WS_MAEMO_5
@@ -72,36 +110,7 @@ LockScreen::LockScreen()
                  "com.nokia.system_ui.signal",
                  "alarm_dialog_status", this, SLOT(onAlarmDialogStatusChanged(QDBusMessage)));
 
-    QString orientation = QSettings().value("Main/Orientation", "Auto").toString().toLower();
-    if (orientation == "landscape"){
-        m_View->setAttribute(Qt::WA_Maemo5LandscapeOrientation);
-        m_WasPortrait = false;
-        //LsWidget::setPortrait(false);
-    } else if (orientation == "portrait"){
-        m_View->setAttribute(Qt::WA_Maemo5PortraitOrientation);        
-        m_WasPortrait = false;
-        //LsWidget::setPortrait(true);
-    }else{
-        m_View->setAttribute(Qt::WA_Maemo5AutoOrientation);
-        /*conn.connect("",
-                     MCE_SIGNAL_PATH,
-                     MCE_SIGNAL_IF,
-                     MCE_DEVICE_ORIENTATION_SIG, this, SLOT(onOrientationChanged(QDBusMessage)));*/
-        connect(QApplication::desktop(), SIGNAL(resized(int)), this, SLOT(onOrientationChanged(int)));
-        //LsWidget::setPortrait(isPortrait());
-        m_WasPortrait = !LsWidget::isPortrait();
-    }
-
     m_View->setAttribute(Qt::WA_Maemo5NonComposited);
-#else
-    QString orientation = QSettings().value("Main/Orientation", "auto").toString().toLower();
-    if (orientation == "portrait"){
-        m_WasPortrait = false;
-        //LsWidget::setPortrait(true);
-    }else{
-        m_WasPortrait = false;
-        //LsWidget::setPortrait(false);
-    }
 #endif    
 
     setHildonFlags();
@@ -139,10 +148,19 @@ bool LockScreen::hide()
 
     m_View->hide();
     QTimer::singleShot(250, this, SLOT(stopUpdate()));
-    //stopUpdate();
     return true;
 }
 
+bool LockScreen::saveScreenshot(QString fileName)
+{
+    qDebug() << "Saving screenshot to:" << fileName;
+    if (LsWidget::getOrientation() == LsWidget::Auto)
+        setSizeAndPosition();
+    m_View->update();
+    QPixmap pixMap = QPixmap::grabWidget(m_View);
+    return pixMap.save(fileName);
+}
+
 bool LockScreen::show()
 {
     if (m_View->isVisible())
@@ -153,8 +171,9 @@ bool LockScreen::show()
 #else
     m_View->show();
 #endif    
-    setSizeAndPosition();
-    m_View->update(m_View->rect());
+    if (LsWidget::getOrientation() == LsWidget::Auto)
+        setSizeAndPosition();
+    m_View->update();
     return true;
 }
 
@@ -211,9 +230,9 @@ void LockScreen::setBackground()
 
     QString bkg;
     if (isPortrait)
-        bkg = QSettings().value("Main/BackGroundImageP", "/opt/usr/share/themes/alpha/backgrounds/lockslider.png").toString();
+        bkg = LockScreen::Settings->value("Main/BackGroundImageP", "/opt/usr/share/themes/alpha/backgrounds/lockslider.png").toString();
     else
-        bkg = QSettings().value("Main/BackGroundImageL", "/opt/usr/share/themes/alpha/backgrounds/lockslider.png").toString();
+        bkg = LockScreen::Settings->value("Main/BackGroundImageL", "/opt/usr/share/themes/alpha/backgrounds/lockslider.png").toString();
 
     if (m_BkgPath != bkg){
         if (!bkg.isEmpty())
@@ -227,7 +246,7 @@ void LockScreen::setBackground()
 
 void LockScreen::createWidgets()
 {
-    QSettings settings;
+    QSettings settings(LockScreen::Settings->fileName(), QSettings::IniFormat);
 
     int size = settings.beginReadArray("Main/Widgets");
     for (int i=0; i<size; i++){
@@ -242,7 +261,6 @@ void LockScreen::createWidgets()
         }
     }
     settings.endArray();
-
     startUpdate();
 }
 
@@ -250,16 +268,16 @@ void LockScreen::onDisplayStateChangedSlot(QString displayState)
 {
 #ifdef Q_WS_MAEMO_5
     qDebug() << "Display state changed:" << displayState;
-    if (displayState == QLatin1String(MCE_DISPLAY_OFF_STRING)) {
-        if (m_tklockState == MCE_TK_LOCKED)
+    m_displayState = displayState;
+    if (displayState == MCE_DISPLAY_OFF_STRING) {
+        if (m_tklockState == MCE_TK_LOCKED && !m_isDialogActive)
             show();
         stopUpdate();
-    }else if (displayState == QLatin1String(MCE_DISPLAY_ON_STRING)) {
+    }else if (displayState == MCE_DISPLAY_ON_STRING) {
         if (m_tklockState == MCE_TK_LOCKED && !m_isDialogActive){            
-            //LsWidget::setPortrait(isPortrait());
-            //setSizeAndPosition();
-            onOrientationChanged(0);
-            startUpdate();            
+            if (LsWidget::getOrientation() == LsWidget::Auto)
+                onOrientationChanged(0);
+            startUpdate();
         }
     }
 #endif
@@ -288,8 +306,11 @@ void LockScreen::onCallStateChanged(QString state)
 #ifdef Q_WS_MAEMO_5
     if (state != MCE_CALL_STATE_NONE)
         m_isDialogActive = true;
-    else
+    else{
         m_isDialogActive = false;
+        if (m_tklockState == MCE_TK_LOCKED && m_displayState == MCE_DISPLAY_OFF_STRING)
+            show();
+    }
 #else
     Q_UNUSED(state)
 #endif
@@ -306,7 +327,8 @@ void LockScreen::onAlarmDialogStatusChanged(QDBusMessage msg)
     m_isDialogActive = status == 5;
     if (m_isDialogActive){
         hide();
-    }
+    }else if (m_tklockState == MCE_TK_LOCKED && m_displayState == MCE_DISPLAY_OFF_STRING)
+        show();
 }
 
 void LockScreen::onIncomingCallSlot(QDBusMessage)
@@ -338,13 +360,7 @@ void LockScreen::stopUpdate()
 
 #ifdef Q_WS_MAEMO_5
 void LockScreen::onOrientationChanged(int)
-//void LockScreen::onOrientationChanged(QDBusMessage msg)
 {
-    /*QVariant val = msg.arguments()[0];
-    qDebug() << "onOrientationChanged:" << val.toString();
-    if (val.toString() != "portrait" && val.toString() != "landscape")
-        return;
-    LsWidget::setPortrait(val.toString() == "portrait");*/
     if (!m_View->isVisible())
         return;
 
@@ -360,7 +376,6 @@ void LockScreen::setSizeAndPosition()
 
         qDebug() << "Orientation changed portrait=" << isPortrait;
         setBackground();
-
         if (isPortrait){
             m_Scene.setSceneRect(0, 0, 480, 800);        
             m_View->setFixedSize(480, 800);
@@ -400,24 +415,3 @@ bool LockScreen::isLocked()
 #endif
     return res;
 }
-
-/*bool LockScreen::isPortrait()
-{
-    bool res = false;
-#ifdef Q_WS_MAEMO_5
-    QDBusConnection conn = QDBusConnection::systemBus();
-    QDBusInterface device(MCE_SERVICE,
-                          MCE_REQUEST_PATH, MCE_REQUEST_IF, conn);
-    QDBusMessage msg = device.call(MCE_DEVICE_ORIENTATION_GET);
-
-    if (msg.arguments().count() > 0 ){
-        QString state = msg.arguments()[0].toString();
-        qDebug() << "Portrait:" << state;
-        res = state == "portrait";
-    }
-#else
-    res = false;
-#endif
-    return res;
-}
-*/
