@@ -18,6 +18,7 @@
 #ifndef LOCKSCREEN_H
 #define LOCKSCREEN_H
 #include <QtGui>
+#include <QSettings>
 #include "widgets/lswidgets.h"
 #include "backends/systemplayer.h"
 
@@ -34,10 +35,12 @@ public:
     LockScreen();
 
     static bool isLocked();
-    //static bool isPortrait();
     bool show();
     bool hide();
     static bool Debug;
+    static bool ScreenshotMode;
+    static QSettings* Settings;
+    bool saveScreenshot(QString);
 
 private:
     bool m_WasPortrait;
@@ -52,6 +55,7 @@ private:
 
     bool m_isDialogActive;
     QString m_tklockState;
+    QString m_displayState;
 
     void startUpdate();
 
@@ -65,7 +69,6 @@ private slots:
     void onTkLockChanged(QString locked);
     void onCallStateChanged(QString);
 #ifdef Q_WS_MAEMO_5
-    //void onOrientationChanged(QDBusMessage);
     void onOrientationChanged(int);
     void onIncomingCallSlot(QDBusMessage);
     void onAlarmDialogStatusChanged(QDBusMessage);
