@@ -45,15 +45,17 @@ void SimpleLoggingHandler(QtMsgType type, const char *msg)
             abort();
     }
 }
+
+void printUsage()
+{
+    qDebug() << "Options:";
+    qDebug() << " -c filename           : use filename as config file";
+    qDebug() << " -s filename           : save a screenshot to filename and exit";
+    qDebug() << " -d                    : debug mode";
+}
+
 int main(int argc, char *argv[])
 {
-#ifdef Q_WS_MAEMO_5
-    LockScreen::Debug = false;
-    if (argc > 1 && QString(argv[1]) == "-d")
-        LockScreen::Debug = true;
-#else
-    LockScreen::Debug = true;
-#endif
     QApplication a(argc, argv);
     a.setOrganizationName("sakya");
     a.setApplicationName("QtLockscreen");
@@ -76,8 +78,43 @@ int main(int argc, char *argv[])
     if (!QFile::exists(name))
         QFile::copy(":/DefaultSettings.conf", name);
 
+    QString screenshotFile;
+    LockScreen::Settings = new QSettings();
+
+#ifdef Q_WS_MAEMO_5
+    LockScreen::Debug = false;
+
+    for (int i=1; i<argc; i++){
+        QString arg = argv[i];
+
+        if (arg == "-h" || arg == "--help"){
+            LockScreen::Debug = true;
+            printUsage();
+            return 0;
+        }else if (arg == "-d")
+            LockScreen::Debug = true;
+        else if (arg == "-c" && argc > i + 1){
+            QString file = argv[i+1];
+            qDebug() << "Using config file:" << file;
+            delete LockScreen::Settings;
+            LockScreen::Settings = NULL;
+            LockScreen::Settings = new QSettings(file, QSettings::IniFormat);
+        } else if (arg == "-s" && argc > i + 1){
+            LockScreen::Debug = true;
+            screenshotFile = argv[i+1];
+            qDebug() << "Saving screenshot to:" << screenshotFile;
+            LockScreen::ScreenshotMode = true;
+        }
+    }
+#else
+    LockScreen::Debug = true;
+#endif
+    qDebug() << a.applicationName() << a.applicationVersion();
+    qDebug() << "Copyright  2011 Paolo Iommarini";
+    qDebug() << "sakya_tg@yahoo.it";
+
     //Translation:
-    QString locale = QSettings().value("Main/Locale", "").toString();
+    QString locale = LockScreen::Settings->value("Main/Locale", "").toString();
     if (!locale.isEmpty()){
         qDebug() << "Locale override:" << locale;
         QLocale l(locale);
@@ -89,15 +126,19 @@ int main(int argc, char *argv[])
     if (translator.load(QString("/opt/qtlockscreen/qtlockscreen_%1").arg(locale)))
         a.installTranslator(&translator);
 
-    qDebug() << a.applicationName() << a.applicationVersion();
-    qDebug() << "Copyright  2011 Paolo Iommarini";
-    qDebug() << "sakya_tg@yahoo.it";
     LockScreen l;
+    int res = 0;
 
-    if (LockScreen::Debug || LockScreen::isLocked())
-        l.show();
-
-    int res = a.exec();
+    if (LockScreen::ScreenshotMode){
+        l.saveScreenshot(screenshotFile);
+        delete LockScreen::Settings;
+    }else{
+        if (LockScreen::Debug || LockScreen::isLocked())
+            l.show();
+        res = a.exec();
+    }
 
+    delete LockScreen::Settings;
+    LockScreen::Settings = NULL;
     return res;
 }
