@@ -73,3 +73,21 @@ void LsMediaAlbumArt::onMetadataChanged(QMap<QString,QVariant> data)
         update();
     }
 }
+
+void LsMediaAlbumArt::onOrientationChanged()
+{
+    //Reload the albumart (the size can be different in portrait and landscape):
+    QSize newSize = getSizeSetting(QSize(size().width(), size().height()));
+    if (newSize.width() != size().width()) {
+        if (!m_ArtPath.isEmpty()){
+            qDebug() << "Reloading album art:" << m_ArtPath;
+            m_AlbumArt = QPixmap(m_ArtPath).scaledToWidth(newSize.width());
+        }else{
+            if (!m_NoCoverImage.isEmpty())
+                m_AlbumArt = QPixmap(m_NoCoverImage).scaledToWidth(newSize.width());
+            else
+                m_AlbumArt = QPixmap();
+        }
+        update();
+    }
+}
