@@ -11,9 +11,12 @@ class LsMovableImage : public QObject, public LsImage
     Q_OBJECT
 public:
     LsMovableImage(QString name="");
+    void paint(QPainter *painter, const QStyleOptionGraphicsItem *option,
+               QWidget *widget);
 
     bool isPressed();
     void setImage(QPixmap);
+    void setPressedImage(QPixmap);
 
 private:
     bool m_IsPressed;
@@ -22,6 +25,8 @@ private:
     QPointF m_PositionBeforeMove;
     qreal m_ZValue;
 
+    QPixmap m_PressedImage;
+
     void setPressed(bool pressed);
 
 protected:
