@@ -139,7 +139,10 @@ void LsNotification::stopUpdate()
 
 void LsNotification::startUpdate()
 {
-    QTimer::singleShot(250, this, SLOT(updateNotification()));
+    if (LockScreen::ScreenshotMode)
+        updateNotification();
+    else
+        QTimer::singleShot(250, this, SLOT(updateNotification()));
 }
 
 void LsNotification::updateNotification()
