@@ -43,6 +43,7 @@ void LsSlideToUnlock::applySettings()
 {
     m_SliderInitialPos = getPosSetting("SliderPos", QPoint(0,0));
     m_Slider->setImage(QPixmap(getSetting("SliderImage", "/opt/qtlockscreen/default/unlock.png").toString()));
+    m_Slider->setPressedImage(QPixmap(getSetting("SliderImagePressed", "").toString()));
     m_Slider->setPos(m_SliderInitialPos);
     m_BackgroundImage = QPixmap(getSetting("BackgroundImage", "").toString());
 
@@ -60,7 +61,7 @@ void LsSlideToUnlock::onSliderMoveEnded()
     QPropertyAnimation *ran = new QPropertyAnimation(m_Slider, "pos");
     ran->setEasingCurve(QEasingCurve::InOutCubic);
     ran->setStartValue(pos);
-    ran->setEndValue(QPointF(0,0));
+    ran->setEndValue(m_SliderInitialPos);
     ran->start(QAbstractAnimation::DeleteWhenStopped);
 }
 
@@ -74,7 +75,7 @@ void LsSlideToUnlock::onSliderMoved(QPointF pos)
     #ifdef Q_WS_MAEMO_5
         QDBusInterface lockScreen("com.nokia.mce", "/com/nokia/mce/request", "com.nokia.mce.request", QDBusConnection::systemBus(), this);
         lockScreen.call("req_tklock_mode_change", "unlocked");
-        m_Slider->setPos(m_SliderInitialPos);
+        mouseReleaseEvent(new QGraphicsSceneMouseEvent());
         if (LockScreen::Debug)
             qApp->quit();
     #else
