@@ -18,8 +18,9 @@
 #include "lswidget.h"
 #include <QApplication>
 #include <QDesktopWidget>
+#include "lockscreen.h"
 
-//bool LsWidget::m_Portrait;
+LsWidget::Orientation LsWidget::m_Orientation;
 
 LsWidget::LsWidget(QString name)
 {
@@ -34,7 +35,7 @@ LsWidget::LsWidget(QString name)
 
 QVariant LsWidget::getSetting(QString name, QVariant defaultValue)
 {
-    return QSettings().value(QString("%1/%2").arg(m_Name).arg(name), defaultValue);
+    return LockScreen::Settings->value(QString("%1/%2").arg(m_Name).arg(name), defaultValue);
 }
 
 QPoint LsWidget::getPosSetting(QPoint defaultValue)
@@ -199,18 +200,30 @@ void LsWidget::update()
 
 bool LsWidget::isPortrait()
 {
-    return QApplication::desktop()->width() < QApplication::desktop()->height();
+    switch (m_Orientation)
+    {
+    case LsWidget::Auto:
+        return QApplication::desktop()->width() < QApplication::desktop()->height();
+        break;
+    case LsWidget::Portrait:
+        return true;
+        break;
+    case LsWidget::Landscape:
+        return false;
+        break;
+    }
+    return false;
 }
 
-/*bool LsWidget::isPortrait()
+LsWidget::Orientation LsWidget::getOrientation()
 {
-    return LsWidget::m_Portrait;
+    return LsWidget::m_Orientation;
 }
 
-void LsWidget::setPortrait(bool portrait)
+void LsWidget::setOrientation(LsWidget::Orientation orientation)
 {
-    LsWidget::m_Portrait = portrait;
-}*/
+    LsWidget::m_Orientation = orientation;
+}
 
 void LsWidget::setSizeAndPosition(QSize defaultSize, QPoint defaultPos)
 {
