@@ -16,6 +16,7 @@
 //    along with this program; if not, write to the Free Software
 //    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 #include "lswifi.h"
+#include "lockscreen.h"
 
 LsWifi::LsWifi(QString name) :
         LsWidget(name.isEmpty() ? "Wifi": name)
@@ -25,6 +26,11 @@ LsWifi::LsWifi(QString name) :
 #ifdef Q_WS_MAEMO_5
     QDBusConnection::systemBus().connect("com.nokia.icd", "/com/nokia/icd", "com.nokia.icd",
                                          "status_changed", this, SLOT(netStateChanged(QString,QString,QString,QString)));
+
+    if (LockScreen::Debug)
+        m_Connected = true;
+#else
+    m_Connected = true;
 #endif
 }
 
